@@ -1,4 +1,4 @@
-__version__ = "0.3.4"
+__version__ = "0.3.7"
 
 from scrapingant_client.client import ScrapingAntClient
 from scrapingant_client.cookie import Cookie
@@ -8,16 +8,20 @@ from scrapingant_client.errors import (
     ScrapingantInvalidInputException,
     ScrapingantInternalException,
     ScrapingantSiteNotReachableException,
+    ScrapingantDetectedException,
 )
+from scrapingant_client.proxy_type import ProxyType
 from scrapingant_client.response import Response
 
 __all__ = [
     'ScrapingAntClient',
     'Cookie',
+    'ProxyType',
     'ScrapingantClientException',
     'ScrapingantInvalidTokenException',
     'ScrapingantInvalidInputException',
     'ScrapingantInternalException',
     'ScrapingantSiteNotReachableException',
+    'ScrapingantDetectedException',
     'Response',
 ]
