@@ -12,7 +12,9 @@ from scrapingant_client.errors import (
     ScrapingantInvalidInputException,
     ScrapingantInternalException,
     ScrapingantSiteNotReachableException,
+    ScrapingantDetectedException,
 )
+from scrapingant_client.proxy_type import ProxyType
 from scrapingant_client.response import Response
 from scrapingant_client.utils import base64_encode_string
 
@@ -33,8 +35,11 @@ class ScrapingAntClient:
             url: str,
             cookies: Optional[List[Cookie]] = None,
             js_snippet: Optional[str] = None,
+            proxy_type: ProxyType = ProxyType.datacenter,
             proxy_country: Optional[str] = None,
             return_text: bool = False,
+            wait_for_selector: Optional[str] = None,
+            browser: bool = True,
     ) -> Response:
         request_data = {'url': url}
         if cookies is not None:
@@ -42,10 +47,13 @@ class ScrapingAntClient:
         if js_snippet is not None:
             encoded_js_snippet = base64_encode_string(js_snippet)
             request_data['js_snippet'] = encoded_js_snippet
+        request_data['proxy_type'] = proxy_type
         if proxy_country is not None:
             request_data['proxy_country'] = proxy_country.lower()
-        if return_text:
-            request_data['return_text'] = True
+        if wait_for_selector is not None:
+            request_data['wait_for_selector'] = wait_for_selector
+        request_data['return_text'] = return_text
+        request_data['browser'] = browser
 
         response = self.requests_session.post(
             SCRAPINGANT_API_BASE_URL + '/general',
@@ -53,10 +61,12 @@ class ScrapingAntClient:
         )
         if response.status_code == 403:
             raise ScrapingantInvalidTokenException()
-        elif response.status_code == 422:
-            raise ScrapingantInvalidInputException(response.text)
         elif response.status_code == 404:
             raise ScrapingantSiteNotReachableException(url)
+        elif response.status_code == 422:
+            raise ScrapingantInvalidInputException(response.text)
+        elif response.status_code == 423:
+            raise ScrapingantDetectedException()
         elif response.status_code == 500:
             raise ScrapingantInternalException()
         json_response = response.json()
